export default {
    "message": "Cannot use 'await' as identifier inside an async function",
    "column": 18,
    "index": 41,
    "lineNumber": 2
}
